==> ejc-zjkjcost-impl-3.0.0-20220627.071725-13-sources.jar: com/ejianc/business/zjkjcost/finish/bean/EstimateEntity.java <==
package com.ejianc.business.zjkjcost.finish.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 竣工考核-履行情况考评-主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_finish_estimate")
public class EstimateEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="apply_id")
    private Long applyId; // 申报主表id
    @TableField(value="apply_code")
    private Long applyCode; // 申报主表code
    @TableField(value="contract_id")
    private Long contractId; // 合同主键
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同code
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="condition_build")
    private String conditionBuild; // 施工目标完成情况
    @TableField(value="condition_technology")
    private String conditionTechnology; // 技术目标完成情况
    @TableField(value="condition_quality")
    private String conditionQuality; // 质量目标完成情况
    @TableField(value="condition_ci")
    private String conditionCi; // CI等目标完成情况
    @TableField(value="condition_settle")
    private String conditionSettle; // 结算目标完成情况
    @TableField(value="condition_capital")
    private String conditionCapital; // 资金目标完成情况
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public Long getApplyCode() {
        return applyCode;
    }

    public void setApplyCode(Long applyCode) {
        this.applyCode = applyCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getConditionBuild() {
        return conditionBuild;
    }

    public void setConditionBuild(String conditionBuild) {
        this.conditionBuild = conditionBuild;
    }
    public String getConditionTechnology() {
        return conditionTechnology;
    }

    public void setConditionTechnology(String conditionTechnology) {
        this.conditionTechnology = conditionTechnology;
    }
    public String getConditionQuality() {
        return conditionQuality;
    }

    public void setConditionQuality(String conditionQuality) {
        this.conditionQuality = conditionQuality;
    }
    public String getConditionCi() {
        return conditionCi;
    }

    public void setConditionCi(String conditionCi) {
        this.conditionCi = conditionCi;
    }
    public String getConditionSettle() {
        return conditionSettle;
    }

    public void setConditionSettle(String conditionSettle) {
        this.conditionSettle = conditionSettle;
    }
    public String getConditionCapital() {
        return conditionCapital;
    }

    public void setConditionCapital(String conditionCapital) {
        this.conditionCapital = conditionCapital;
    }
    
}

==> ejc-zjkjcost-impl-3.0.0-20220628.072801-17-sources.jar: com/ejianc/business/zjkjcost/finish/bean/EstimateEntity.java <==
package com.ejianc.business.zjkjcost.finish.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 竣工考核-履行情况考评-主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_finish_estimate")
public class EstimateEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="apply_id")
    private Long applyId; // 申报主表id
    @TableField(value="apply_code")
    private String applyCode; // 申报主表code
    @TableField(value="contract_id")
    private Long contractId; // 合同主键
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同code
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="condition_build")
    private String conditionBuild; // 施工目标完成情况
    @TableField(value="condition_technology")
    private String conditionTechnology; // 技术目标完成情况
    @TableField(value="condition_quality")
    private String conditionQuality; // 质量目标完成情况
    @TableField(value="condition_ci")
    private String conditionCi; // CI等目标完成情况
    @TableField(value="condition_settle")
    private String conditionSettle; // 结算目标完成情况
    @TableField(value="condition_capital")
    private String conditionCapital; // 资金目标完成情况
    @TableField(value="condition_safe")
    private String conditionSafe; // 安全目标完成情况
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getConditionSafe() {
        return conditionSafe;
    }

    public void setConditionSafe(String conditionSafe) {
        this.conditionSafe = conditionSafe;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public String getApplyCode() {
        return applyCode;
    }

    public void setApplyCode(String applyCode) {
        this.applyCode = applyCode;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getConditionBuild() {
        return conditionBuild;
    }

    public void setConditionBuild(String conditionBuild) {
        this.conditionBuild = conditionBuild;
    }
    public String getConditionTechnology() {
        return conditionTechnology;
    }

    public void setConditionTechnology(String conditionTechnology) {
        this.conditionTechnology = conditionTechnology;
    }
    public String getConditionQuality() {
        return conditionQuality;
    }

    public void setConditionQuality(String conditionQuality) {
        this.conditionQuality = conditionQuality;
    }
    public String getConditionCi() {
        return conditionCi;
    }

    public void setConditionCi(String conditionCi) {
        this.conditionCi = conditionCi;
    }
    public String getConditionSettle() {
        return conditionSettle;
    }

    public void setConditionSettle(String conditionSettle) {
        this.conditionSettle = conditionSettle;
    }
    public String getConditionCapital() {
        return conditionCapital;
    }

    public void setConditionCapital(String conditionCapital) {
        this.conditionCapital = conditionCapital;
    }
    
}
